==> oe_python_template_example-0.1.15.tar.gz: oe_python_template_example-0.1.15/CHANGELOG.md <==
[🧠 OE Python Template Example](https://oe-python-template-example.readthedocs.io/en/latest/)

## [0.1.15](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.1.14..0.1.15) - 2025-03-15

### ⚙️ Miscellaneous Tasks

- .gitignore - ([b1fb3fa](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/b1fb3fa01b18031cfa12f3241b62e70dc1419640))


## [0.1.13](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.1.12..v0.1.13) - 2025-03-14

### 📚 Documentation

- Adapt - ([6e99c1d](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/6e99c1d604c8e9fe4094b6a21d95619181ea0d14))


## [0.1.7](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.1.6..v0.1.7) - 2025-03-14

### Deps

- *(template)* Bump - ([d9ca816](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/d9ca816eb70ff526b659a892b35b139daeed2235))


## [0.0.7](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.4..v0.0.7) - 2025-03-08

### ⚙️ Miscellaneous Tasks

- *(template)* Bump - ([355683b](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/355683b69c3ef67461b9d7a562c71fcd5e048ad9))


## [0.0.4](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.3..v0.0.4) - 2025-03-02

### 📚 Documentation

- Update - ([45fbb4d](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/45fbb4d287dc8575bbe5895f14f52186a42e8c56))


## [0.0.3](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.2..v0.0.3) - 2025-03-02

### ⚙️ Miscellaneous Tasks

- Docker.io username - ([afc5d08](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/afc5d08c6ccc5f6c6c3824600c4e0fdef1690154))
- Copier from repo - ([fa01793](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/fa017930245289f795bbfe9a3204f75103fd19bc))


## [0.0.2] - 2025-03-02

### ⛰️  Features

- Initial commit - ([7986b87](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/7986b87fef683b0274acc87c6a11404f13de874e))

### ⚙️ Miscellaneous Tasks

- Bump - ([21554f6](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/21554f61f5cee12c9595b71381888bfa281c8005))

## New Contributors ❤️

* @helmut-hoffer-von-ankershoffen made their first contribution

==> oe_python_template_example-0.1.19.tar.gz: oe_python_template_example-0.1.19/CHANGELOG.md <==
[🧠 OE Python Template Example](https://oe-python-template-example.readthedocs.io/en/latest/)

## [0.1.15](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.1.14..v0.1.15) - 2025-03-15

### ⚙️ Miscellaneous Tasks

- .gitignore - ([b1fb3fa](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/b1fb3fa01b18031cfa12f3241b62e70dc1419640))


## [0.1.13](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.1.12..v0.1.13) - 2025-03-14

### 📚 Documentation

- Adapt - ([6e99c1d](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/6e99c1d604c8e9fe4094b6a21d95619181ea0d14))


## [0.1.7](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.1.6..v0.1.7) - 2025-03-14

### Deps

- *(template)* Bump - ([d9ca816](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/d9ca816eb70ff526b659a892b35b139daeed2235))


## [0.0.7](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.4..v0.0.7) - 2025-03-08

### ⚙️ Miscellaneous Tasks

- *(template)* Bump - ([355683b](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/355683b69c3ef67461b9d7a562c71fcd5e048ad9))


## [0.0.4](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.3..v0.0.4) - 2025-03-02

### 📚 Documentation

- Update - ([45fbb4d](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/45fbb4d287dc8575bbe5895f14f52186a42e8c56))


## [0.0.3](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.2..v0.0.3) - 2025-03-02

### ⚙️ Miscellaneous Tasks

- Docker.io username - ([afc5d08](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/afc5d08c6ccc5f6c6c3824600c4e0fdef1690154))
- Copier from repo - ([fa01793](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/fa017930245289f795bbfe9a3204f75103fd19bc))


## [0.0.2] - 2025-03-02

### ⛰️  Features

- Initial commit - ([7986b87](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/7986b87fef683b0274acc87c6a11404f13de874e))

### ⚙️ Miscellaneous Tasks

- Bump - ([21554f6](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/21554f61f5cee12c9595b71381888bfa281c8005))

## New Contributors ❤️

* @helmut-hoffer-von-ankershoffen made their first contribution
